==> hinemos_src-4.1.0.tar.gz: HinemosManager/src_collectiverun/com/clustercontrol/collectiverun/model/CrunTypeMstEntity.java <==
package com.clustercontrol.collectiverun.model;

import java.io.Serializable;
import javax.persistence.*;

import com.clustercontrol.commons.util.JpaTransactionManager;

import java.util.List;


/**
 * The persistent class for the cc_crun_type_mst database table.
 * 
 */
@Entity
@Table(name="cc_crun_type_mst")
@Cacheable(true)
public class CrunTypeMstEntity implements Serializable {
	private static final long serialVersionUID = 1L;
	private String typeId;
	private String nameId;
	private Integer orderNo;
	private List<CrunCmdMstEntity> crunCmdMstEntities;

	@Deprecated
	public CrunTypeMstEntity() {
	}

	public CrunTypeMstEntity(String typeId) {
		this.setTypeId(typeId);
		EntityManager em = new JpaTransactionManager().getEntityManager();
		em.persist(this);
	}

	@Id
	@Column(name="type_id")
	public String getTypeId() {
		return this.typeId;
	}

	public void setTypeId(String typeId) {
		this.typeId = typeId;
	}


	@Column(name="name_id")
	public String getNameId() {
		return this.nameId;
	}

	public void setNameId(String nameId) {
		this.nameId = nameId;
	}


	@Column(name="order_no")
	public Integer getOrderNo() {
		return this.orderNo;
	}

	public void setOrderNo(Integer orderNo) {
		this.orderNo = orderNo;
	}


	//bi-directional many-to-one association to CrunCmdMstEntity
	@OneToMany(mappedBy="crunTypeMstEntity", cascade=CascadeType.ALL, orphanRemoval=true)
	public List<CrunCmdMstEntity> getCrunCmdMstEntities() {
		return this.crunCmdMstEntities;
	}

	public void setCrunCmdMstEntities(List<CrunCmdMstEntity> crunCmdMstEntities) {
		this.crunCmdMstEntities = crunCmdMstEntities;
	}

}

==> hinemos_src-4.1.1.tar.gz: HinemosManager/src_collectiverun/com/clustercontrol/collectiverun/model/CrunTypeMstEntity.java <==
package com.clustercontrol.collectiverun.model;

import java.io.Serializable;
import javax.persistence.*;

import com.clustercontrol.commons.util.JpaTransactionManager;

import java.util.List;


/**
 * The persistent class for the cc_crun_type_mst database table.
 * 
 */
@Entity
@Table(name="cc_crun_type_mst")
@Cacheable(true)
public class CrunTypeMstEntity implements Serializable {
	private static final long serialVersionUID = 1L;
	private String typeId;
	private String nameId;
	private Integer orderNo;
	private List<CrunCmdMstEntity> crunCmdMstEntities;

	@Deprecated
	public CrunTypeMstEntity() {
	}

	public CrunTypeMstEntity(String typeId) {
		this.setTypeId(typeId);
		EntityManager em = new JpaTransactionManager().getEntityManager();
		em.persist(this);
	}

	@Id
	@Column(name="type_id")
	public String getTypeId() {
		return this.typeId;
	}

	public void setTypeId(String typeId) {
		this.typeId = typeId;
	}


	@Column(name="name_id")
	public String getNameId() {
		return this.nameId;
	}

	public void setNameId(String nameId) {
		this.nameId = nameId;
	}


	@Column(name="order_no")
	public Integer getOrderNo() {
		return this.orderNo;
	}

	public void setOrderNo(Integer orderNo) {
		this.orderNo = orderNo;
	}


	//bi-directional many-to-one association to CrunCmdMstEntity
	@OneToMany(mappedBy="crunTypeMstEntity", cascade=CascadeType.ALL)
	public List<CrunCmdMstEntity> getCrunCmdMstEntities() {
		return this.crunCmdMstEntities;
	}

	public void setCrunCmdMstEntities(List<CrunCmdMstEntity> crunCmdMstEntities) {
		this.crunCmdMstEntities = crunCmdMstEntities;
	}

}
